@@ -17,6 +17,7 @@
 ################################################################################
 import os
 import tempfile
+import warnings
 
 from typing import List, Any, Optional, cast
 
@@ -93,13 +94,13 @@ class StreamExecutionEnvironment(object):
     def set_max_parallelism(self, max_parallelism: int) -> 'StreamExecutionEnvironment':
         """
         Sets the maximum degree of parallelism defined for the program. The upper limit (inclusive)
-        is 32767.
+        is 32768.
 
         The maximum degree of parallelism specifies the upper limit for dynamic scaling. It also
         defines the number of key groups used for partitioned state.
 
         :param max_parallelism: Maximum degree of parallelism to be used for the program,
-                                with 0 < maxParallelism <= 2^15 - 1.
+                                with 0 < maxParallelism <= 2^15.
         :return: This object.
         """
         self._j_stream_execution_environment = \
@@ -213,6 +214,15 @@ class StreamExecutionEnvironment(object):
         """
         return self._j_stream_execution_environment.isChainingEnabled()
 
+    def is_chaining_of_operators_with_different_max_parallelism_enabled(self) -> bool:
+        """
+        Returns whether operators that have a different max parallelism can be chained.
+
+        :return: True if chaining is enabled, false otherwise
+        """
+        return self._j_stream_execution_environment\
+            .isChainingOfOperatorsWithDifferentMaxParallelismEnabled()
+
     def get_checkpoint_config(self) -> CheckpointConfig:
         """
         Gets the checkpoint config, which defines values like checkpoint interval, delay between
@@ -321,7 +331,14 @@ class StreamExecutionEnvironment(object):
 
         :param state_backend: The :class:`StateBackend`.
         :return: This object.
+
+        .. note:: Deprecated since version 1.19: This method is deprecated and will be removed in
+                  future FLINK major version. Use `stream_execution_environment.configure` method
+                  instead to set the state backend.
         """
+        warnings.warn("Deprecated since version 1.19: This method is deprecated and will be removed"
+                      " in future FLINK major version. Use `stream_execution_environment.configure`"
+                      " method instead to set the state backend.", DeprecationWarning)
         self._j_stream_execution_environment = \
             self._j_stream_execution_environment.setStateBackend(state_backend._j_state_backend)
         return self
@@ -415,7 +432,14 @@ class StreamExecutionEnvironment(object):
 
         :param restart_strategy_configuration: Restart strategy configuration to be set.
         :return:
+
+        .. note:: Deprecated since version 1.19: This method is deprecated and will be removed in
+                  future FLINK major version. Use `stream_execution_environment.configure` method
+                  instead to set the restart strategy.
         """
+        warnings.warn("Deprecated since version 1.19: This method is deprecated and will be removed"
+                      " in future FLINK major version. Use `stream_execution_environment.configure`"
+                      " method instead to set the restart strategy.", DeprecationWarning)
         self._j_stream_execution_environment.setRestartStrategy(
             restart_strategy_configuration._j_restart_strategy_configuration)
 
@@ -440,7 +464,16 @@ class StreamExecutionEnvironment(object):
         :param type_class_name: The full-qualified java class name of the types serialized with the
                                 given serializer.
         :param serializer_class_name: The full-qualified java class name of the serializer to use.
+
+        .. note:: Deprecated since version 1.19: Register data types and serializers through hard
+                  codes is deprecated, because you need to modify the codes when upgrading job
+                  version. You should configure this by option `pipeline.serialization-config`.
         """
+        warnings.warn("Deprecated since version 1.19: Register data types and serializers through"
+                      " hard codes is deprecated, because you need to modify the codes when"
+                      " upgrading job version. You should configure this by config option "
+                      " 'pipeline.serialization-config'.", DeprecationWarning)
+
         type_clz = load_java_class(type_class_name)
         j_serializer_clz = load_java_class(serializer_class_name)
         self._j_stream_execution_environment.addDefaultKryoSerializer(type_clz, j_serializer_clz)
@@ -459,7 +492,15 @@ class StreamExecutionEnvironment(object):
         :param type_class_name: The full-qualified java class name of the types serialized with
                                 the given serializer.
         :param serializer_class_name: The full-qualified java class name of the serializer to use.
+
+        .. note:: Deprecated since version 1.19: Register data types and serializers through hard
+                  codes is deprecated, because you need to modify the codes when upgrading job
+                  version. You should configure this by option `pipeline.serialization-config`.
         """
+        warnings.warn("Deprecated since version 1.19: Register data types and serializers through"
+                      " hard codes is deprecated, because you need to modify the codes when"
+                      " upgrading job version. You should configure this by config option "
+                      " 'pipeline.serialization-config'.", DeprecationWarning)
         type_clz = load_java_class(type_class_name)
         j_serializer_clz = load_java_class(serializer_class_name)
         self._j_stream_execution_environment.registerTypeWithKryoSerializer(
@@ -478,7 +519,15 @@ class StreamExecutionEnvironment(object):
             >>> env.register_type("com.aaa.bbb.TypeClass")
 
         :param type_class_name: The full-qualified java class name of the type to register.
+
+        .. note:: Deprecated since version 1.19: Register data types and serializers through hard
+                  codes is deprecated, because you need to modify the codes when upgrading job
+                  version. You should configure this by option `pipeline.serialization-config`.
         """
+        warnings.warn("Deprecated since version 1.19: Register data types and serializers through"
+                      " hard codes is deprecated, because you need to modify the codes when"
+                      " upgrading job version. You should configure this by config option "
+                      " 'pipeline.serialization-config'.", DeprecationWarning)
         type_clz = load_java_class(type_class_name)
         self._j_stream_execution_environment.registerType(type_clz)
 
@@ -683,11 +732,11 @@ class StreamExecutionEnvironment(object):
         .. note::
 
             Please make sure the uploaded python environment matches the platform that the cluster
-            is running on and that the python version must be 3.6 or higher.
+            is running on and that the python version must be 3.7 or higher.
 
         .. note::
 
-            The python udf worker depends on Apache Beam (version == 2.38.0).
+            The python udf worker depends on Apache Beam (version == 2.43.0).
             Please ensure that the specified environment meets the above requirements.
 
         :param python_exec: The path of python interpreter.
@@ -708,11 +757,12 @@ class StreamExecutionEnvironment(object):
         jars_key = jvm.org.apache.flink.configuration.PipelineOptions.JARS.key()
         env_config = jvm.org.apache.flink.python.util.PythonConfigUtil \
             .getEnvironmentConfig(self._j_stream_execution_environment)
-        old_jar_paths = env_config.getString(jars_key, None)
-        joined_jars_path = ';'.join(jars_path)
-        if old_jar_paths and old_jar_paths.strip():
-            joined_jars_path = ';'.join([old_jar_paths, joined_jars_path])
-        env_config.setString(jars_key, joined_jars_path)
+        old_jars_path = env_config.getString(jars_key, None)
+        old_jars_list = Configuration.parse_list_value(
+            old_jars_path,
+            jvm.org.apache.flink.configuration.GlobalConfiguration.isStandardYaml())
+        joined_jars_list = [*old_jars_list, *jars_path]
+        env_config.setString(jars_key, str(joined_jars_list))
 
     def add_classpaths(self, *classpaths: str):
         """
@@ -727,10 +777,12 @@ class StreamExecutionEnvironment(object):
         env_config = jvm.org.apache.flink.python.util.PythonConfigUtil \
             .getEnvironmentConfig(self._j_stream_execution_environment)
         old_classpaths = env_config.getString(classpaths_key, None)
-        joined_classpaths = ';'.join(list(classpaths))
-        if old_classpaths and old_classpaths.strip():
-            joined_classpaths = ';'.join([old_classpaths, joined_classpaths])
-        env_config.setString(classpaths_key, joined_classpaths)
+        old_classpaths_list = Configuration.parse_list_value(
+            old_classpaths,
+            jvm.org.apache.flink.configuration.GlobalConfiguration.isStandardYaml()
+        )
+        joined_classpaths_list = [*old_classpaths_list, *classpaths]
+        env_config.setString(classpaths_key, str(joined_classpaths_list))
 
     def get_default_local_parallelism(self) -> int:
         """
@@ -818,7 +870,7 @@ class StreamExecutionEnvironment(object):
         method returns a local execution environment.
 
         When executed from the command line the given configuration is stacked on top of the
-        global configuration which comes from the flink-conf.yaml, potentially overriding
+        global configuration which comes from the config.yaml, potentially overriding
         duplicated options.
 
         :param configuration: The configuration to instantiate the environment with.
